@@ -14,8 +14,10 @@ class Menu(models.Model):
         'self', related_name='%(class)s_parent', verbose_name=_('Parent menu item'),
         null=True, blank=True, on_delete=models.PROTECT)
     name = models.CharField(_('Menu item name'), max_length=80)
-    view = models.CharField(_('View'), max_length=80, default='')
+    view = models.CharField(_('View'), max_length=125, default='', db_index=True)
     sort_order = models.SmallIntegerField(_('Sort order'), default=0)
+    hidden = models.BooleanField(_('Hidden item'), default=True, db_index=True)
+    enabled = models.BooleanField(_('Enabled item'), default=True, db_index=True)
 
     i18n = TranslationField(fields=('name',))
 
